@@ -51,6 +51,7 @@ linconstrain <- function(x,print=TRUE,indent="  ",exo=FALSE,...) {
 
 ##' @export
 "intfix" <- function(object,...) UseMethod("intfix")
+
 ##' @export
 "intfix<-" <- function(object,...,value) UseMethod("intfix<-")
 
@@ -119,8 +120,7 @@ linconstrain <- function(x,print=TRUE,indent="  ",exo=FALSE,...) {
 "intercept" <- function(object,...) UseMethod("intercept")
 
 ##' @export
-##' @export
-intercept.lvm <- intfix.lvm <- function(object,value,...) {
+intercept.lvm <- function(object,value,...) {
     if (!missing(value)) {
         intercept(object,...) <- value
         return(object)
@@ -132,12 +132,14 @@ intercept.lvm <- intfix.lvm <- function(object,value,...) {
     return(res)
 }
 
+##' @export
+intfix.lvm <- intercept.lvm
+
 ##' @export
 "intercept<-" <- function(object,...,value) UseMethod("intercept<-")
 
 ##' @export
-##' @export
-"intercept<-.lvm" <- "intfix<-.lvm" <- function(object, vars,...,value) {
+"intercept<-.lvm" <- function(object, vars,...,value) {
     if (!missing(vars) && inherits(value,"formula")) value <- all.vars(value)
     if (inherits(value,"formula")) {
         lhs <- getoutcome(value)
@@ -166,6 +168,12 @@ intercept.lvm <- intfix.lvm <- function(object,value,...) {
     return(object)
 }
 
+##' @export
+"intfix<-.lvm" <- function(object, ..., value) {
+  intercept(object, ...) <- value
+  object
+}
+
 ###}}} intfix
 
 ###{{{ covfix
